/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a copy
 * of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock;

import java.util.List;
import nl.cloudfarming.client.model.CropProtection;
import nl.cloudfarming.client.model.crop.Crop;

/**
 *
 * @author Timon Veenstra
 */
public interface StockService {

    /**
     * Close a CropProtection.
     * Fills the endDate with today
     * @param cropProtection
     * @return returns true if datUntil was null false if dateUntil was already set.
     */
    boolean endCropProtection(CropProtection cropProtection);

    /**
     * Find all the Persisted CropProtections
     * @return a List of found CropProtections
     */
    List<CropProtection> findAllCropProtections();

    /**
     * Find the CropProtection based on it's authorization number
     * @param authorizationNumber the authorization number to look for
     * @return CropProtection if found
     * TODO applicationMethod is a workaround authorizationNumbers should be unique 
     */
    List<CropProtection> findCropProtectionByAuthorizationNumberAndApplicationMethod(int authorizationNumber, String applicationMethod);

    /**
     * Find all the CropProtection object for a certain crop
     * @param crop the crop to find the CropProtection for
     * @return all the CropProtections found
     */
    List<CropProtection> getCropProtectionByCrop(Crop crop);

    /**
     * Persist the CropProtection in transaction
     * @param cropProtection The CropProtection to persist in transaction
     */
    void persistInTransaction(CropProtection cropProtection);

    /**
     * Remove persisted CropProtections
     * @param cropProtection the CropProtection to persist
     */
    void removeCropProtection(CropProtection cropProtection);
    
}
